pub struct BranchNode {
pub new_name: String,
pub ca: ContentAddr,
pub path: Vec<Id>,
}Expand description
Branch a named node: create a new name with its own commit for the given content address, and replace the node with a reference to it.
Fields
new_name: Stringca: ContentAddrpath: Vec<Id>Path from root to the NamedRef node (last element = node index).