pub struct LabelToggle<'a> { /* private fields */ }Expand description
A toggle widget that behaves like a label but can be toggled on/off.
Implementations
Sourceimpl<'a> LabelToggle<'a>
impl<'a> LabelToggle<'a>
Sourcepub fn new(text: impl Into<WidgetText>, selected: &'a mut bool) -> Self
pub fn new(text: impl Into<WidgetText>, selected: &'a mut bool) -> Self
Create a new LabelToggle from raw text
Sourcepub fn from_label(label: Label, selected: &'a mut bool) -> Self
pub fn from_label(label: Label, selected: &'a mut bool) -> Self
Create a LabelToggle from an existing Label This allows using all Label options like wrap(), truncate(), etc.